@@ -2,6 +2,7 @@
 Fake model used for testing and verification.
 """
 import itertools
+import pytricia
 from preseem import NetworkMetadataEntity, NetworkMetadataReference
 
 class FakeNetworkMetadataModel(object):
@@ -10,6 +11,7 @@ class FakeNetworkMetadataModel(object):
         self.refs_by_type = refs_by_type
         self.refs = {}                  # public: current references
         self.nms = {}                   # public: current entities
+        self.pt4 = pytricia.PyTricia(32)
         self._index = {x.type: {} for x in indexes or []}
         for index in indexes or []:
             self._index[index.type][index.attribute] = {}
@@ -26,6 +28,8 @@ class FakeNetworkMetadataModel(object):
     async def set_nm(self, entity):
         assert isinstance(entity, NetworkMetadataEntity)
         self.nms[entity.network_prefix] = entity
+        if ':' not in entity.network_prefix:
+            self.pt4[entity.network_prefix] = entity
         if self._cbk:
             await self._cbk(entity, deleted=False)
 
@@ -33,6 +37,7 @@ class FakeNetworkMetadataModel(object):
         assert isinstance(entity, NetworkMetadataEntity)
         try:
             del self.nms[entity.network_prefix]
+            del self.pt4[entity.network_prefix]
             if self._cbk:
                 await self._cbk(entity, deleted=True)
         except AttributeError:
