@@ -4,6 +4,8 @@ from itertools import chain
 import logging
 import socket
 
+import pytricia
+
 from preseem_grpc_model import network_metadata_pb2
 from preseem.grpc_client import PreseemGrpcClient
 
@@ -127,6 +129,7 @@ class PreseemNetworkMetadataModel(object):
         self.refs_by_type = refs_by_type
         self.refs = {}                  # public: current references
         self.nms = {}                   # public: current entities
+        self.pt4 = pytricia.PyTricia(32)
         self.syn = None  # dict of GRPC objects we receive in synchronize state
         self.nm_syn = None
         self.start_load = None
@@ -155,6 +158,10 @@ class PreseemNetworkMetadataModel(object):
             self.nm_syn = {}
         if msg.action == network_metadata_pb2.NetworkMetadataEntityAction.LOADED:
             self.nms = self.nm_syn
+            self.pt4 = pytricia.PyTricia(32)
+            for ip, nm in self.nms.items():
+                if ':' not in ip:
+                    self.pt4[ip] = nm
             self.nm_syn = None
             if self._cbk:
                 for nm in self.nms.values():
@@ -175,12 +182,18 @@ class PreseemNetworkMetadataModel(object):
                         pass
             else:
                 self.nm_syn[nm.network_prefix] = nm
+                if ':' not in msg.entity.network_prefix:
+                    self.pt4[msg.entity.network_prefix] = nm
         elif msg.action == network_metadata_pb2.NetworkMetadataEntityAction.DELETE:
             nm = self._make_nm(msg.entity)
             try:
                 del self.nms[nm.network_prefix]
             except KeyError:
                 pass
+            try:
+                del self.pt4[nm.network_prefix]
+            except KeyError:
+                pass
             if self._cbk:
                 try:
                     await self._cbk(nm, deleted=True)
